VapiMissingAssistantException class
Thrown when neither assistantId nor assistant is provided to the start method.
At least one of these parameters must be provided to start a call:
assistantId: ID of a pre-configured assistantassistant: Inline assistant configuration object
- Inheritance
-
- Object
- VapiException
- VapiMissingAssistantException
Constructors
- VapiMissingAssistantException()
-
const
Properties
- details → dynamic
-
Optional additional details about the error.
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
A human-readable description of the error.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited